==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF85S.sql <==
/****************************************************************************/
/* GF85 ( 移行DB対応明細 )                                                  */
/*                                                                          */
/* Created : 2015/11/16 16:20:15                                            */
/****************************************************************************/
CREATE TABLE GF85 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (    1 )                  NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   varchar           (   50 )                  NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          varchar           (   30 )                  NOT NULL            /*  40 項目         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  50 表示順       */
 , NAME_JA      varchar           (  200 )                                      /*  60 名称         */
 , CLS_NAME     varchar           (   10 )                  NOT NULL            /*  70 DBｸﾗｽ        */
 , USE_LENGTH   varchar           (    9 )                                      /*  80 使用桁数     */
 , DATA_DEFAULT varchar           (  200 )                                      /*  90 初期値       */
 , NOT_NULL     varchar           (    1 )                                      /* 100 ﾉｯﾄﾇﾙ        */
 , FGCOM        varchar           (    1 )      DEFAULT 0   NOT NULL            /* 110 共通項目F    */
 , BIKO         varchar           ( 2000 )                                      /* 120 備考         */
 , NOJUN        INTEGER                         DEFAULT 0   NOT NULL            /* 130 対応順       */
 , CONV_FUNC    varchar           (  500 )                                      /* 140 変換関数     */
 , F_CONST      varchar           (  200 )                                      /* 150 元固定値     */
 , F_SYSTEM_ID  varchar           (   10 )                                      /* 160 元ｼｽﾃﾑID     */
 , F_TABLE_NAME varchar           (   50 )                                      /* 170 元ﾃｰﾌﾞﾙ名    */
 , F_CLM        varchar           (   30 )                                      /* 180 元項目       */
 , F_SEQNO      INTEGER                         DEFAULT 0   NOT NULL            /* 190 元表示順     */
 , F_NAME_JA    varchar           (  200 )                                      /* 200 元名称       */
 , F_CLS_NAME   varchar           (   10 )                                      /* 210 元DBｸﾗｽ      */
 , F_USE_LENGTH varchar           (    9 )                                      /* 220 元使用桁数   */
 , F_BIKO       varchar           ( 2000 )                                      /* 230 元備考       */
 , DESCRIPTION  varchar           ( 4000 )                                      /* 240 概要説明     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion6.4.2.0_dev.zip: uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF85S.sql <==
/****************************************************************************/
/* GF85 ( 移行DB対応明細 )                                                  */
/*                                                                          */
/* Created : 2016/01/07 17:07:27                                            */
/****************************************************************************/
CREATE TABLE GF85 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TABLE_NAME   varchar           (   50 )                  NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          varchar           (   30 )                  NOT NULL            /*  40 項目         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  50 表示順       */
 , NAME_JA      varchar           (  200 )                                      /*  60 名称         */
 , CLS_NAME     varchar           (   10 )                  NOT NULL            /*  70 DBｸﾗｽ        */
 , USE_LENGTH   varchar           (    9 )                                      /*  80 使用桁数     */
 , DATA_DEFAULT varchar           (  200 )                                      /*  90 初期値       */
 , NOT_NULL     varchar           (    1 )                                      /* 100 ﾉｯﾄﾇﾙ        */
 , KBCLM        varchar           (    1 )      DEFAULT 0   NOT NULL            /* 120 ｶﾗﾑ区分      */
 , BIKO         varchar           ( 2000 )                                      /* 130 備考         */
 , NOJUN        INTEGER                         DEFAULT 0   NOT NULL            /* 140 対応順       */
 , CONV_FUNC    varchar           (  500 )                                      /* 150 変換関数     */
 , F_CLM        varchar           ( 1000 )                                      /* 190 元項目       */
 , F_NAME_JA    varchar           (  200 )                                      /* 210 元名称       */
 , F_CLS_NAME   varchar           (   10 )                                      /* 220 元DBｸﾗｽ      */
 , F_USE_LENGTH varchar           (    9 )                                      /* 230 元使用桁数   */
 , F_BIKO       varchar           ( 2000 )                                      /* 240 元備考       */
 , DESCRIPTION  varchar           ( 4000 )                                      /* 250 概要説明     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
